summaryrefslogtreecommitdiff
path: root/lisp/jka-compr.el
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2012-01-20 16:41:05 -0800
committerGlenn Morris <rgm@gnu.org>2012-01-20 16:41:05 -0800
commit7b447e9bda80e5de478922771a62c2b3a8f9b2aa (patch)
treea37394ac2c36ea1d6e31f1b2dc954c3e8bc7e9d3 /lisp/jka-compr.el
parenta2f0118ce5c18ea397c9571e401231b2fca7aa61 (diff)
downloademacs-7b447e9bda80e5de478922771a62c2b3a8f9b2aa.tar.gz
File-local variable fixes.
* lisp/files.el (local-enable-local-variables): Doc fix. (inhibit-local-variables-regexps): Rename from inhibit-first-line-modes-regexps. Keep old name as obsolete alias. Doc fix. Add some extensions from auto-coding-alist. (inhibit-local-variables-suffixes): Rename from inhibit-first-line-modes-suffixes. Doc fix. (inhibit-local-variables-p): New function, extracted from set-auto-mode-1. (set-auto-mode): Doc fix. Respect inhibit-local-variables-regexps. (set-auto-mode-1): Doc fix. Use inhibit-local-variables-p. (hack-local-variables): Doc fix. Make the mode-only case respect enable-local-variables and friends. Respect inhibit-local-variables-regexps for file-locals, but not for directory-locals. (set-visited-file-name): Take account of inhibit-local-variables-regexps. Whether it applies may change as the file name is changed. * lisp/jka-cmpr-hook.el (jka-compr-install): * lisp/jka-compr.el (jka-compr-uninstall): Update for inhibit-first-line-modes-suffixes name change. * etc/NEWS: Mention this change. Fixes: debbugs:10506
Diffstat (limited to 'lisp/jka-compr.el')
-rw-r--r--lisp/jka-compr.el9
1 files changed, 4 insertions, 5 deletions
diff --git a/lisp/jka-compr.el b/lisp/jka-compr.el
index 786e4292d5f..8a8d7cdbb52 100644
--- a/lisp/jka-compr.el
+++ b/lisp/jka-compr.el
@@ -657,16 +657,15 @@ It is not recommended to set this variable permanently to anything but nil.")
(defun jka-compr-uninstall ()
"Uninstall jka-compr.
This removes the entries in `file-name-handler-alist' and `auto-mode-alist'
-and `inhibit-first-line-modes-suffixes' that were added
+and `inhibit-local-variables-suffixes' that were added
by `jka-compr-installed'."
;; Delete from inhibit-first-line-modes-suffixes
;; what jka-compr-install added.
(mapc
(function (lambda (x)
(and (jka-compr-info-strip-extension x)
- (setq inhibit-first-line-modes-suffixes
+ (setq inhibit-local-variables-suffixes
(delete (jka-compr-info-regexp x)
- inhibit-first-line-modes-suffixes)))))
+ inhibit-local-variables-suffixes)))))
jka-compr-compression-info-list--internal)
(let* ((fnha (cons nil file-name-handler-alist))
@@ -657,16 +657,15 @@ It is not recommended to set this variable permanently to anything but nil.")
by `jka-compr-installed'."
- ;; Delete from inhibit-first-line-modes-suffixes
- ;; what jka-compr-install added.
+ ;; Delete from inhibit-local-variables-suffixes what jka-compr-install added.
(mapc
(function (lambda (x)